"""
Constants for csle-cluster
"""


class KIBANA_TUNNELS:
    """
    Constants related to Kibana tunnels
    """
    KIBANA_TUNNELS_DICT = {}
    KIBANA_TUNNEL_BASE_PORT = 17000
    THREAD_PROPERTY = "thread"


class RYU_TUNNELS:
    """
    Constants related to Ryu tunnels
    """
    RYU_TUNNELS_DICT = {}
    RYU_TUNNEL_BASE_PORT = 18000
    THREAD_PROPERTY = "thread"
